DragonLog - Keyboard Shortcuts
==============================

Main actions
------------

| Action               | Shortcut         |
|----------------------|------------------|
| Log QSO              | Ctrl + L         |
| Edit QSO(s)          | Ctrl + E         |
| Delete QSO(s)        | Ctrl + X         |
| Copy QSO(s) as table | Ctrl + C         |
| Watch file           | Ctrl + W         |
| Show filter          | Ctrl + F         |
| Reset filter         | Ctrl + R         |
| Show contest stats   | Ctrl + T         |
| Show console         | Ctrl + K         |
| Show DX Spots        | Ctrl + D         |
| Check eQSL           | Ctrl + Alt + E   |
| Download eQSL        | Ctrl + Shift + E |
| Check LotW           | Ctrl + Alt + L   |
| Quit                 | Ctrl + Q         |
| Mark QSL sent        | Ctrl + Alt + S   |
| Unmark QSL sent      | Ctrl + Shift + S |
| Mark QSL rcvd        | Ctrl + Alt + R   |
| Unmark QSL rcvd      | Ctrl + Shift + R |
| Mark HamQTH uploaded | Ctrl + Alt + U   |
| Change contest       | Ctrl + Alt + C   |


QSO form actions
----------------

| Action         | Shortcut         |
|----------------|------------------|
| Save QSO       | Ctrl + S         |
| Search HamQTH  | Ctrl + Alt + H   |
| Search QRZ     | Ctrl + Shift + Q |
| Search QRZCQ   | Ctrl + Alt + Z   |
| Start time now | Ctrl + Alt + N   |


Statistics actions
------------------

| Action             | Shortcut |
|--------------------|----------|
| Copy data as table | Ctrl + C |
